Jabol.Migration (Jabol v0.1.1)

Migration system for Jabol database schemas.

This module provides functionality for database migrations similar to Ecto.Migration but simplified for the Jabol system.

Summary

Functions

Adds a column to the current table.

Alters an existing table.

Creates a new table with the given name and columns.

Drops a table from the database.

Functions

add(column_name, type, opts \\ [])

(macro)

Adds a column to the current table.

alter_table(table_name, list)

(macro)

Alters an existing table.

create_index(table_name, columns, opts \\ [])

(macro)

Creates a database index.

create_table(table_name, list)

(macro)

Creates a new table with the given name and columns.

drop_index(table_name, columns, opts \\ [])

(macro)

Drops a database index.

drop_table(table_name)

(macro)

Drops a table from the database.