Jabol.Migration (Jabol v0.1.1)
View SourceMigration system for Jabol database schemas.
This module provides functionality for database migrations similar to Ecto.Migration but simplified for the Jabol system.
Summary
Functions
Adds a column to the current table.
Alters an existing table.
Creates a database index.
Creates a new table with the given name and columns.
Drops a database index.
Drops a table from the database.
Functions
Adds a column to the current table.
Alters an existing table.
Creates a database index.
Creates a new table with the given name and columns.
Drops a database index.
Drops a table from the database.